@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2011-2017 Canonical
+ * Copyright (C) 2011-2018 Canonical
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -214,7 +214,6 @@ static cpu_freq_scale_t cpu_freq_scale[] = {
 	{ 1e10, 1e9,  "GHz" },
 	{ 1e13, 1e12, "THz" },
 	{ 1e16, 1e15, "PHz" },
-	{ -1.0, -1.0,  NULL }
 };
 
 /* seconds scale suffixes, secs, mins, hours, etc */
@@ -706,7 +705,7 @@ static inline uint64_t OPTIMIZE3 HOT get_ticks(void)
 static char *secs_to_str(const double secs)
 {
 	static char buf[16];
-	int i;
+	size_t i;
 
 	for (i = 0; i < 5; i++) {
 		if (secs <= second_scales[i + 1].scale)
@@ -727,7 +726,7 @@ static void get_tm(const double time_now, struct tm *tm)
 	time_t now = (time_t)time_now;
 
 	if (UNLIKELY((now == ((time_t) -1)))) {
-		memset(tm, 0, sizeof(struct tm));
+		memset(tm, 0, sizeof(*tm));
 	} else {
 		(void)localtime_r(&now, tm);
 	}
@@ -886,7 +885,7 @@ no_cmd:
 		 * a new info struct
 		 */
 		if (!info) {
-			info = malloc(sizeof(pid_info_t));
+			info = malloc(sizeof(*info));
 			new_info = true;
 		}
 
@@ -978,7 +977,7 @@ static void OPTIMIZE3 HOT sample_add(
 	 * list since time is assumed to be increasing
 	 */
 	if (!found) {
-		if (UNLIKELY((sdl = malloc(sizeof(sample_delta_list_t))) == NULL)) {
+		if (UNLIKELY((sdl = malloc(sizeof(*sdl))) == NULL)) {
 			fprintf(stderr, "Cannot allocate sample delta list\n");
 			exit(EXIT_FAILURE);
 		}
@@ -995,7 +994,7 @@ static void OPTIMIZE3 HOT sample_add(
 	}
 
 	/* Now append the sdi onto the list */
-	if (UNLIKELY((sdi = malloc(sizeof(sample_delta_item_t))) == NULL)) {
+	if (UNLIKELY((sdi = malloc(sizeof(*sdi))) == NULL)) {
 		fprintf(stderr, "Cannot allocate sample delta item\n");
 		exit(EXIT_FAILURE);
 	}
@@ -1047,7 +1046,7 @@ static void info_banner_dump(const double time_now)
 {
 	static char str[256];
 	static char *hdrptr;
-	char *ptr = str;
+	char *ptr;
 	int i;
 
 	if (!hdrptr) {
@@ -1171,7 +1170,7 @@ static void samples_dump(
 	double first_time = -1.0;
 
 	if (UNLIKELY((sorted_cpu_infos =
-	     calloc(cpu_info_list_length, sizeof(cpu_info_t*))) == NULL)) {
+	     calloc(cpu_info_list_length, sizeof(*sorted_cpu_infos))) == NULL)) {
 		fprintf(stderr,
 			"Cannot allocate buffer for sorting cpu_infos\n");
 		exit(EXIT_FAILURE);
@@ -1390,11 +1389,11 @@ static cpu_info_t OPTIMIZE3 HOT *cpu_info_find(
 			return info;
 	}
 
-	if (UNLIKELY((info = malloc(sizeof(cpu_info_t))) == NULL)) {
+	if (UNLIKELY((info = malloc(sizeof(*info))) == NULL)) {
 		fprintf(stderr, "Cannot allocate CPU info\n");
 		exit(EXIT_FAILURE);
 	}
-	memcpy(info, new_info, sizeof(cpu_info_t));
+	memcpy(info, new_info, sizeof(*info));
 
 	if ((new_info->cmdline == NULL) || (opt_flags & OPT_CMD_COMM)) {
 		info->cmdline = info->comm;
@@ -1482,7 +1481,7 @@ static uint32_t OPTIMIZE3 HOT hash_djb2a(const pid_t pid, const char *str)
 static void cpu_stat_free_contents(
 	cpu_stat_t *cpu_stats[])	/* CPU stat hash table */
 {
-	int i;
+	size_t i;
 
 	for (i = 0; i < TABLE_SIZE; i++) {
 		cpu_stat_t *cs = cpu_stats[i];
@@ -1534,7 +1533,7 @@ static void OPTIMIZE3 HOT cpu_stat_add(
 		cs_new = cpu_stat_free_list;
 		cpu_stat_free_list = cs_new->next;
 	} else {
-		if (UNLIKELY((cs_new = malloc(sizeof(cpu_stat_t))) == NULL)) {
+		if (UNLIKELY((cs_new = malloc(sizeof(*cs_new))) == NULL)) {
 			fprintf(stderr,
 				"Out of memory allocating a cpu stat\n");
 			exit(1);
@@ -1608,7 +1607,7 @@ static void cpu_stat_diff(
 	cpu_stat_t *const cpu_stats_old[],	/* old CPU stats samples */
 	cpu_stat_t *const cpu_stats_new[])	/* new CPU stats samples */
 {
-	int i;
+	size_t i;
 	cpu_stat_t *sorted = NULL;
 	const bool do_sample_add = (opt_flags & OPT_SAMPLES);
 
@@ -1683,7 +1682,7 @@ static int get_proc_stat(proc_stat_t *proc_stat)
 	FILE *fp;
 	char buffer[4096];
 
-	memset(proc_stat, 0, sizeof(proc_stat_t));
+	memset(proc_stat, 0, sizeof(*proc_stat));
 
 	fp = fopen("/proc/stat", "r");
 	if (UNLIKELY(!fp))
@@ -1891,7 +1890,7 @@ static void get_cpustats(
  */
 static double cpu_freq_average(uint32_t max_cpus)
 {
-	unsigned int i, n = 0;
+	size_t i, n = 0;
 	double total_freq = 0;
 
 	for (i = 0; i < max_cpus; i++) {
@@ -1934,7 +1933,7 @@ static char *cpu_freq_format(double freq)
 	double scale = 1e18;
 	size_t i;
 
-	for (i = 0; cpu_freq_scale[i].suffix; i++) {
+	for (i = 0; i < SIZEOF_ARRAY(cpu_freq_scale); i++) {
 		if (freq < cpu_freq_scale[i].threshold) {
 			suffix = cpu_freq_scale[i].suffix;
 			scale = cpu_freq_scale[i].scale;
@@ -2253,8 +2252,9 @@ int main(int argc, char **argv)
 		exit(EXIT_FAILURE);
 	}
 
-	cpu_stats_old = calloc(TABLE_SIZE, sizeof(cpu_stat_t*));
-	cpu_stats_new = calloc(TABLE_SIZE, sizeof(cpu_stat_t*));
+	cpu_stats_old = calloc(TABLE_SIZE, sizeof(*cpu_stats_old));
+	cpu_stats_new = calloc(TABLE_SIZE, sizeof(*cpu_stats_new));
+
 	if (UNLIKELY(cpu_stats_old == NULL || cpu_stats_new == NULL)) {
 		fprintf(stderr, "Cannot allocate CPU statistics tables\n");
 		exit(EXIT_FAILURE);
